Class: YieldStarClient::PropertyParameters

Inherits:
Modelish::Base
  • Object
show all
Defined in:
lib/yield_star_client/property_methods.rb

Overview

Represents the pricing parameters for a particular property.

This object is guaranteed to have an external_property_id; all other attributes may be nil.

Instance Attribute Summary collapse

Instance Attribute Details

#external_property_idString

the ID of the property



50
51
52
# File 'lib/yield_star_client/property_methods.rb', line 50

def external_property_id
  @external_property_id
end

#max_move_in_daysInteger

number of fixed move in date options to return in response to a request for lease rates.



50
51
52
# File 'lib/yield_star_client/property_methods.rb', line 50

def max_move_in_days
  @max_move_in_days
end

#max_new_lease_termInteger

maximum length (in months) of a new lease term



50
51
52
# File 'lib/yield_star_client/property_methods.rb', line 50

def max_new_lease_term
  @max_new_lease_term
end

#max_renewal_lease_termInteger

maximum length (in months) of a renewal lease term



50
51
52
# File 'lib/yield_star_client/property_methods.rb', line 50

def max_renewal_lease_term
  @max_renewal_lease_term
end

#min_new_lease_termInteger

minimum length (in months) of a new lease term



50
51
52
# File 'lib/yield_star_client/property_methods.rb', line 50

def min_new_lease_term
  @min_new_lease_term
end

#min_renewal_lease_termInteger

minimum length (in months) of a renewal lease term



50
51
52
# File 'lib/yield_star_client/property_methods.rb', line 50

def min_renewal_lease_term
  @min_renewal_lease_term
end

#new_lease_term_optionsInteger

absolute number of lease term options to offer on either side of the base lease term when creating the lease term rent matrix.



50
51
52
# File 'lib/yield_star_client/property_methods.rb', line 50

def new_lease_term_options
  @new_lease_term_options
end

#post_dateDate

the post date of the latest Price Optimizer forecasting and optimization nightly run.



50
51
52
# File 'lib/yield_star_client/property_methods.rb', line 50

def 
  @post_date
end